#######################################################
#######################################################
############    COPYRIGHT - DATA SOCIETY   ############
#######################################################
#######################################################

##########################################
##   BUILDING A COMPLEX GRAPH ANSWERS   ##
##########################################

## NOTE: To run individual pieces of code, 
## select the line of code and press ctrl + enter for Windows
## and command + enter for Macs

# Your code does not need to match up exactly - these answers
# are examples of how to execute the exercises below, but you may
# have found other ways to get the same output. 

#==================================================================================

# We're going to visualize the length of time and number of instances a bikeshare 
# station is unable to be utilized because it is full (can't deposit bikes) or 
# empty (can't take out bikes). 

# 1. Read in the data CaBi.status and view the data.

# Read in files

setwd("~/Desktop/")
CaBi.status = read.csv("CaBi.status.csv")    
View(CaBi.status)

# 2. Pull up the categories (names of each column) of CaBi.status.

names(CaBi.status)

# 3. How many stations are in the data set?

levels(CaBi.status$Station.Name)

# 4. Create a table that counts up the occurrences at each station.
#    Label it CaBi.subset.

CaBi.subset = table(CaBi.status$Terminal.Number)
View(CaBi.subset)

# 5. Make CaBi.subset into a data frame so we will be able to sort it.

CaBi.subset = as.data.frame(CaBi.subset)

# 6. Order CaBi.subset by Freq and call it CaBi.subset.order.

CaBi.subset.order = CaBi.subset[order(CaBi.subset$Freq, decreasing = T),]
View(CaBi.subset.order)

# 7. Take the stations in rows 65-69: 31113, 31250, 31261, 31262, 31271
#    and create a new data set with only those stations. Name the data
#    as CaBi.midfive.

CaBi.midfive = CaBi.status[CaBi.status$Terminal.Number %in% c("31113", "31250", 
                                                              "31261", "31262", 
                                                              "31271"),]
View(CaBi.midfive)

# 8. Create a bubble plot with CaBi.midfive, where x is the Start.Time,
#    y is the Day, and size is Duration.min. Label the graph as 
#    CaBi.graph1.

CaBi.graph1 = ggplot(CaBi.midfive,   
                   aes(x = Start.Time,        
                       y = Day,          
                       size = Duration.min)) + 
  geom_point() 

CaBi.graph1

# 9. Replace the x axis with the Decimal.Start column, and label
#    this graph as CaBi.graph2.

CaBi.graph2 = ggplot(CaBi.midfive,   
                       aes(x = Decimal.Start,        
                           y = Day,          
                           size = Duration.min)) + 
  geom_point()

CaBi.graph2

# 10. Add in the fill color by Station.Name and label the graph
#     CaBi.graph3.

CaBi.graph3 = ggplot(CaBi.midfive,   
                    aes(x = Decimal.Start,        
                        y = Day,          
                        size = Duration.min,
                        fill = Station.Name)) + 
  geom_point() 

CaBi.graph3

# 11. Move the fill and size to the geom_point argument, and add
#     the shape as 21. Label the new graph CaBi.graph4.

CaBi.graph4 = ggplot(CaBi.midfive,   
                   aes(x = Decimal.Start,        
                       y = Day)) + 
  geom_point(aes(size = Duration.min,
                 fill = Station.Name),
             shape = 21) 

CaBi.graph4

# 12. Add the size_scale_continuous() function with a range from 3 to 10, 
#     and the alpha argument as .55 in geom_point argument. Label it as 
#     CaBi.graph5.

CaBi.graph5 = ggplot(CaBi.midfive,   
                   aes(x = Decimal.Start,        
                       y = Day)) + 
  scale_size_continuous(range = c(3, 10)) + 
  geom_point(aes(fill = Station.Name, 
                 size = Duration.min),
             shape = 21, 
             alpha = .55)

CaBi.graph5


# 13. Adjust the x axis so the tick-marks denote "Midnight" for 0, 
#     "6 am" for 6, "Noon" for 12, and "6 pm" for 18. Rorder the y-axis 
#     with the 'limits' argument in the scale_y_discrete() function. 

CaBi.graph6 = ggplot(CaBi.midfive,   
                   aes(x = Decimal.Start,        
                       y = Day)) + 
  scale_size_continuous(range = c(3, 10)) + 
  scale_x_continuous(breaks = c(0, 6, 12, 18),
                     labels = c("Midnight", "6 am", "Noon", "6 pm")) +
  scale_y_discrete(limits = c("Wednesday", "Thursday", "Friday",
                              "Saturday", "Sunday", "Monday", 
                              "Tuesday")) + 
geom_point(aes(fill = Station.Name, 
               size = Duration.min),
           shape = 21, 
           alpha = .55)

CaBi.graph6

# 14. Add theme_minimal() to the graph and label it CaBi.graph7.

CaBi.graph7 = ggplot(CaBi.midfive,   
                       aes(x = Decimal.Start,        
                           y = Day)) + 
  scale_size_continuous(range = c(3, 10)) + 
  scale_x_continuous(breaks = c(0, 6, 12, 18),
                     labels = c("Midnight", "6 am", "Noon", "6 pm")) +
  scale_y_discrete(limits = c("Wednesday", "Thursday", "Friday",
                              "Saturday", "Sunday", "Monday", 
                              "Tuesday")) + 
  geom_point(aes(fill = Station.Name, 
                 size = Duration.min),
             shape = 21, 
             alpha = .55) +
  theme_minimal()
 
CaBi.graph7

# 15. Adjust the labels on the following and label the new graph CaBi.graph7:
# Legend title for size = Length of time (min)
# Legend title for fill = Location of station
# x axis title = Time of Day
# y axis title = Day of the Week
# Title = Capital Bikeshare station outages from June 17 - June 23, 2015

CaBi.graph8 = ggplot(CaBi.midfive,   
                   aes(x = Decimal.Start,        
                       y = Day)) + 
  scale_size_continuous(range = c(3, 10)) +
  scale_x_continuous(breaks = c(0, 6, 12, 18),
                     labels = c("Midnight", "6 am", "Noon", "6 pm")) +
  scale_y_discrete(limits = c("Wednesday", "Thursday", "Friday",
                              "Saturday", "Sunday", "Monday", 
                              "Tuesday")) + 
  geom_point(aes(fill = Station.Name, 
                 size = Duration.min),
             shape = 21, 
             alpha = .55) +
  labs(size = "Length of time (min)",
       fill = "Location of station",
       x = "Time of day",
       y = "Day of the Week",
       title = "Capital Bikeshare outages in DC from June 17 
       - June 23, 2015") + 
  theme_minimal()

CaBi.graph8

# 16. Facet wrap this graph by location and label it CaBi.graph9.

CaBi.graph9 = ggplot(CaBi.midfive,   
                   aes(x = Decimal.Start,        
                       y = Day)) + 
  scale_size_continuous(range = c(3, 10)) +
  scale_x_continuous(breaks = c(0, 6, 12, 18),
                     labels = c("Midnight", "6 am", "Noon", "6 pm")) +
  scale_y_discrete(limits = c("Wednesday", "Thursday", "Friday",
                              "Saturday", "Sunday", "Monday", 
                              "Tuesday")) + 
  geom_point(aes(fill = Station.Name, 
                 size = Duration.min),
             shape = 21, 
             alpha = .55) +
  labs(size = "Length of time (min)",
       fill = "Location of station",
       x = "Time of day",
       y = "Day of the Week",
       title = "Capital Bikeshare outages in DC from June 17 
       - June 23, 2015") + 
  facet_wrap(~Station.Name) + 
  theme_minimal()

CaBi.graph9

# 17. Save your graph as "Capital Bikeshare.png".

setwd("~/Desktop")
ggsave("Capital Bikeshare.png", 
       width = 10, 
       height = 5.62, 
       units = "in")

# Continue to practice visualizing data with different subsets
# so you become more comfortable in R.

